@@ -31,6 +31,7 @@ import os.path
 import re
 import copy
 import gobject
+import pango
 import pycentrino_globals as pglobals
 
 def delete_node(nodo):
@@ -60,7 +61,16 @@ class pycentrinoApplet(gnome.applet.Applet):
         
     def cleanup(self,event):
         del self.applet
-    
+
+    # font definition
+    def define_font(self):
+        fd = pango.FontDescription()
+        fd.set_family("Helvetica")
+        fd.set_style(pango.STYLE_ITALIC)
+        fd.set_weight(pango.WEIGHT_BOLD)
+        fd.set_size(10 * pango.SCALE)
+        return fd
+        
     # this callback is for update the applet from system info every 1 second
     def timeout_callback(self,event):
 
@@ -68,6 +78,8 @@ class pycentrinoApplet(gnome.applet.Applet):
         self.orientation = self.applet.get_orient()
         self.size = self.applet.get_size()
 
+        # when we delete the children, they run out of references,
+        # so the garbage collector must delete them totally
         for i in (self.box.get_children()):
             self.box.remove(i)
 
@@ -92,14 +104,31 @@ class pycentrinoApplet(gnome.applet.Applet):
 
                 # add un hbox para meter contenido
                 self.box.get_children()[cont].add(gtk.HBox())
+                if i==3:
+                    if self.info[i] == "powersave":
+                        tmp = gtk.Image()
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'powersave.png'))
+                        self.box.get_children()[cont].get_children()[0].pack_start(tmp)
+                    elif self.info[i] == "performance":
+                        tmp = gtk.Image()
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'performance.png'))
+                        self.box.get_children()[cont].get_children()[0].pack_start(tmp)
+                    elif self.info[i] == "userspace":
+                        tmp = gtk.Image()
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'userspace.png'))
+                        self.box.get_children()[cont].get_children()[0].pack_start(tmp)
+
                 # si metemos la informacin de que procesador es, metemos imagen correspondiente
-                if i == 4:
+                elif i==4:
                     if self.info[i] == "centrino":
                         tmp = gtk.Image()
-                        tmp.set_from_file(os.path.join(pglobals.image_dir,'centrino_46.gif'))
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'centrino_46.png'))
                         self.box.get_children()[cont].get_children()[0].pack_start(tmp)
                 else:
+                    fd = self.define_font()
+                    
                     tmp = gtk.Label(self.info[i])
+                    tmp.modify_font(fd)
                     self.box.get_children()[cont].get_children()[0].pack_start(tmp)
 
         #self.applet.hide()
@@ -350,14 +379,28 @@ class pycentrinoApplet(gnome.applet.Applet):
                 
                 # add un hbox para meter contenido
                 self.box.get_children()[cont].add(gtk.HBox())
+                if i == 3:
+                    if self.info[i] == "powersave":
+                        tmp = gtk.Image()
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'powersave.png'))
+                        self.box.get_children()[cont].get_children()[0].pack_start(tmp)
+                    elif self.info[i] == "performance":
+                        tmp = gtk.Image()
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'performance.png'))
+                        self.box.get_children()[cont].get_children()[0].pack_start(tmp)
+                    elif self.info[i] == "userspace":
+                        tmp = gtk.Image()
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'userspace.png'))
+                        self.box.get_children()[cont].get_children()[0].pack_start(tmp)
 
                 # si metemos la informacin de que procesador es, metemos imagen correspondiente
-                if i == 4:
+                elif i == 4:
                     if self.info[i] == "centrino":
                         tmp = gtk.Image()
-                        tmp.set_from_file(os.path.join(pglobals.image_dir,'centrino_46.gif'))
+                        tmp.set_from_file(os.path.join(pglobals.image_dir,'centrino_46.png'))
                         self.box.get_children()[cont].get_children()[0].pack_start(tmp)
                 else:
+                    fd = self.define_font()
                     tmp = gtk.Label(self.info[i])
                     self.box.get_children()[cont].get_children()[0].pack_start(tmp)
 
